@@ -12,7 +12,12 @@ def all_file(root, patterns='*.pyc', ignore_dirs=[], \
     """
     patterns = tuple([p.strip() for p in patterns.split(',')])
     for path, subdirs, files in os.walk(root):
-        if os.path.basename(path) in ignore_dirs:
+        ig = False
+        for ignore_dir in ignore_dirs:
+            if path.startswith(ignore_dir)
+                ig = True
+                break
+        if ig:
             continue
         for pattern in patterns:
             fs = fnmatch.filter(files, pattern)
@@ -31,7 +36,7 @@ def clean(args, logger=None, no_matchs=False):
     filter = args.filter
     ignore_dirs = []
     if args.ignore_dirs:
-        ignore_dirs = args.ignore_dirs.split(',')
+        ignore_dirs = [os.path.join(args.path, d.strip()) for d in args.ignore_dirs.split(',')]
     path = args.path
     for f in all_file(path, filter, ignore_dirs, logger=logger, \
             no_matchs=no_matchs):
